GDExtensionCallableCustomInfo2 class final

Inheritance
Implemented types
Available extensions

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
call_func ↔ GDExtensionCallableCustomCall
getter/setter pair
callable_userdata ↔ GDExtensionObjectPtr
getter/setter pair
equal_func ↔ GDExtensionClassPropertyCanRevert
getter/setter pair
free_func ↔ GDExtensionClassReference
getter/setter pair
get_argument_count_func ↔ GDExtensionCallableCustomGetArgumentCount
getter/setter pair
hash_func ↔ GDExtensionCallableCustomHash
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
is_valid_func ↔ GDExtensionCallableCustomIsValid
getter/setter pair
less_than_func ↔ GDExtensionClassPropertyCanRevert
getter/setter pair
object_id ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
to_string_func ↔ GDExtensionClassToString
getter/setter pair
token ↔ GDExtensionObjectPtr
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited